@@ -91,7 +91,7 @@ class Exceptions:
 
 class ElasticLoadBalancingClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html)
     """
 
@@ -109,7 +109,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Adds the specified tags to the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#add_tags)
         """
 
@@ -120,7 +120,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Associates one or more security groups with your load balancer in a virtual
         private cloud (VPC).
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#apply_security_groups_to_load_balancer)
         """
 
@@ -131,7 +131,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Adds one or more subnets to the set of configured subnets for the specified load
         balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#attach_load_balancer_to_subnets)
         """
 
@@ -139,7 +139,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#can_paginate)
         """
 
@@ -150,7 +150,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Specifies the health check settings to use when evaluating the health state of
         your EC2 instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#configure_health_check)
         """
 
@@ -161,18 +161,18 @@ class ElasticLoadBalancingClient(BaseClient):
         Generates a stickiness policy with sticky session lifetimes that follow that of
         an application-generated cookie.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_app_cookie_stickiness_policy)
         """
 
     def create_lb_cookie_stickiness_policy(
-        self, *, LoadBalancerName: str, PolicyName: str, CookieExpirationPeriod: int = None
+        self, *, LoadBalancerName: str, PolicyName: str, CookieExpirationPeriod: int = ...
     ) -> Dict[str, Any]:
         """
         Generates a stickiness policy with sticky session lifetimes controlled by the
         lifetime of the browser (user-agent) or a specified expiration period.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_lb_cookie_stickiness_policy)
         """
 
@@ -181,16 +181,16 @@ class ElasticLoadBalancingClient(BaseClient):
         *,
         LoadBalancerName: str,
         Listeners: Sequence["ListenerTypeDef"],
-        AvailabilityZones: Sequence[str] = None,
-        Subnets: Sequence[str] = None,
-        SecurityGroups: Sequence[str] = None,
-        Scheme: str = None,
-        Tags: Sequence["TagTypeDef"] = None
+        AvailabilityZones: Sequence[str] = ...,
+        Subnets: Sequence[str] = ...,
+        SecurityGroups: Sequence[str] = ...,
+        Scheme: str = ...,
+        Tags: Sequence["TagTypeDef"] = ...
     ) -> CreateAccessPointOutputTypeDef:
         """
         Creates a Classic Load Balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer)
         """
 
@@ -200,7 +200,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Creates one or more listeners for the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_listeners)
         """
 
@@ -210,12 +210,12 @@ class ElasticLoadBalancingClient(BaseClient):
         LoadBalancerName: str,
         PolicyName: str,
         PolicyTypeName: str,
-        PolicyAttributes: Sequence["PolicyAttributeTypeDef"] = None
+        PolicyAttributes: Sequence["PolicyAttributeTypeDef"] = ...
     ) -> Dict[str, Any]:
         """
         Creates a policy with the specified attributes for the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_policy)
         """
 
@@ -223,7 +223,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Deletes the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer)
         """
 
@@ -233,7 +233,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Deletes the specified listeners from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_listeners)
         """
 
@@ -243,7 +243,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Deletes the specified policy from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_policy)
         """
 
@@ -253,29 +253,29 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Deregisters the specified instances from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#deregister_instances_from_load_balancer)
         """
 
     def describe_account_limits(
-        self, *, Marker: str = None, PageSize: int = None
+        self, *, Marker: str = ..., PageSize: int = ...
     ) -> DescribeAccountLimitsOutputTypeDef:
         """
         Describes the current Elastic Load Balancing resource limits for your AWS
         account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_account_limits)
         """
 
     def describe_instance_health(
-        self, *, LoadBalancerName: str, Instances: Sequence["InstanceTypeDef"] = None
+        self, *, LoadBalancerName: str, Instances: Sequence["InstanceTypeDef"] = ...
     ) -> DescribeEndPointStateOutputTypeDef:
         """
         Describes the state of the specified instances with respect to the specified
         load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_instance_health)
         """
 
@@ -285,38 +285,38 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Describes the attributes for the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_attributes)
         """
 
     def describe_load_balancer_policies(
-        self, *, LoadBalancerName: str = None, PolicyNames: Sequence[str] = None
+        self, *, LoadBalancerName: str = ..., PolicyNames: Sequence[str] = ...
     ) -> DescribeLoadBalancerPoliciesOutputTypeDef:
         """
         Describes the specified policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policies)
         """
 
     def describe_load_balancer_policy_types(
-        self, *, PolicyTypeNames: Sequence[str] = None
+        self, *, PolicyTypeNames: Sequence[str] = ...
     ) -> DescribeLoadBalancerPolicyTypesOutputTypeDef:
         """
         Describes the specified load balancer policy types or all load balancer policy
         types.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policy_types)
         """
 
     def describe_load_balancers(
-        self, *, LoadBalancerNames: Sequence[str] = None, Marker: str = None, PageSize: int = None
+        self, *, LoadBalancerNames: Sequence[str] = ..., Marker: str = ..., PageSize: int = ...
     ) -> DescribeAccessPointsOutputTypeDef:
         """
         Describes the specified the load balancers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancers)
         """
 
@@ -324,7 +324,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Describes the tags associated with the specified load balancers.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_tags)
         """
 
@@ -335,7 +335,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Removes the specified subnets from the set of configured subnets for the load
         balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#detach_load_balancer_from_subnets)
         """
 
@@ -346,7 +346,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Removes the specified Availability Zones from the set of Availability Zones for
         the specified load balancer in EC2-Classic or a default VPC.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#disable_availability_zones_for_load_balancer)
         """
 
@@ -357,21 +357,21 @@ class ElasticLoadBalancingClient(BaseClient):
         Adds the specified Availability Zones to the set of Availability Zones for the
         specified load balancer in EC2-Classic or a default VPC.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#enable_availability_zones_for_load_balancer)
         """
 
     def generate_presigned_url(
         self,
         ClientMethod: str,
-        Params: Mapping[str, Any] = None,
+        Params: Mapping[str, Any] = ...,
         ExpiresIn: int = 3600,
-        HttpMethod: str = None,
+        HttpMethod: str = ...,
     ) -> str:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#generate_presigned_url)
         """
 
@@ -381,7 +381,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Modifies the attributes of the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#modify_load_balancer_attributes)
         """
 
@@ -391,7 +391,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Adds the specified instances to the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#register_instances_with_load_balancer)
         """
 
@@ -401,7 +401,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Removes one or more tags from the specified load balancer.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#remove_tags)
         """
 
@@ -411,7 +411,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
         Sets the certificate that terminates the specified listener's SSL connections.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_listener_ssl_certificate)
         """
 
@@ -422,7 +422,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Replaces the set of policies associated with the specified port on which the EC2
         instance is listening with a new set of policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_for_backend_server)
         """
 
@@ -433,7 +433,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Replaces the current set of policies for the specified load balancer port with
         the specified set of policies.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_of_listener)
         """
 
@@ -442,7 +442,7 @@ class ElasticLoadBalancingClient(BaseClient):
         self, operation_name: Literal["describe_account_limits"]
     ) -> DescribeAccountLimitsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeaccountlimitspaginator)
         """
 
@@ -451,7 +451,7 @@ class ElasticLoadBalancingClient(BaseClient):
         self, operation_name: Literal["describe_load_balancers"]
     ) -> DescribeLoadBalancersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/paginators.html#describeloadbalancerspaginator)
         """
 
@@ -460,7 +460,7 @@ class ElasticLoadBalancingClient(BaseClient):
         self, waiter_name: Literal["any_instance_in_service"]
     ) -> AnyInstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
         """
 
@@ -469,13 +469,13 @@ class ElasticLoadBalancingClient(BaseClient):
         self, waiter_name: Literal["instance_deregistered"]
     ) -> InstanceDeregisteredWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
         """
