@@ -26,6 +26,8 @@ __all__ = (
     "InstanceDeregisteredWaiterName",
     "InstanceInServiceWaiterName",
     "ServiceName",
+    "PaginatorName",
+    "WaiterName",
 )
 
 
@@ -304,10 +306,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -315,3 +319,5 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal["describe_account_limits", "describe_load_balancers"]
+WaiterName = Literal["any_instance_in_service", "instance_deregistered", "instance_in_service"]
