@@ -33,7 +33,7 @@ __all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "Instance
 
 class AnyInstanceInServiceWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
     """
 
@@ -41,18 +41,18 @@ class AnyInstanceInServiceWaiter(Boto3Waiter):
         self,
         *,
         LoadBalancerName: str,
-        Instances: Sequence["InstanceTypeDef"] = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        Instances: Sequence["InstanceTypeDef"] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#anyinstanceinservicewaiter)
         """
 
 
 class InstanceDeregisteredWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
     """
 
@@ -60,18 +60,18 @@ class InstanceDeregisteredWaiter(Boto3Waiter):
         self,
         *,
         LoadBalancerName: str,
-        Instances: Sequence["InstanceTypeDef"] = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        Instances: Sequence["InstanceTypeDef"] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instancederegisteredwaiter)
         """
 
 
 class InstanceInServiceWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
     """
 
@@ -79,10 +79,10 @@ class InstanceInServiceWaiter(Boto3Waiter):
         self,
         *,
         LoadBalancerName: str,
-        Instances: Sequence["InstanceTypeDef"] = None,
-        WaiterConfig: WaiterConfigTypeDef = None
+        Instances: Sequence["InstanceTypeDef"] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters.html#instanceinservicewaiter)
         """
